@@ -26,7 +26,7 @@ from pre_workbench.structinfo import display_styles
 
 grammar_file = os.path.join(os.path.dirname(__file__), "format_info.lark")
 logging.info("grammar_file: %s", grammar_file)
-fi_parser = Lark(open(grammar_file), parser="lalr", start=["start","anytype","expression"])
+fi_parser = Lark(open(grammar_file), parser="lalr", start=["start","anytype","expression"], maybe_placeholders=True)
 
 
 class Evaluator(Transformer):
